import { NPTEventModel } from "@/types/event/NPTEventModel";

export interface RenderDataEventRenderer {
  iconCls: string;
  eventRecord: NPTEventModel;
  cls: Record<string, boolean>;
  wrapperCls: Record<string, boolean>;
  left: number;
  width: number;
  height: number;
  eventStyle: string;
  eventColor: string;
  children: Record<string, unknown>[];
  resourceId: string;
}

export const colors = {
  RED: "#f44336",
  PINK: "#EC407A",
  PURPLE: "#9c27b0",
  VIOLET: "#7E57C2",
  DEEP_BLUE: "#3f51b5",
  BLUE: "#2196f3",
  TURQUOISE: "#26C6DA",
  DEEP_GREEN: "#009688",
  GREEN: "#4caf50",
  LIME: "#cddc39",
  YELLOW: "#e4d127",
  ORANGE: "#ff9800",
  DEEP_ORANGE: "#ff5722",
  GREY: "#9e9e9e"
};

const colorArray = Object.values(colors);

export function getColorByProjectID(id: string): string {
  if (!id) id = "";
  const totalCharCode = id.split("").reduce((sum, char) => (sum += char.charCodeAt(0)), 0);
  return colorArray[totalCharCode % colorArray.length];
}

export function eventRenderer({
  eventRecord,
  renderData
}: {
  eventRecord: NPTEventModel;
  renderData: RenderDataEventRenderer;
}) {
  const eventColor = getColorByProjectID(eventRecord.workcenter);
  renderData.eventColor = eventColor;

  // renderData.cls["highlight-fade"] = true;

  if (eventRecord.field<boolean>("overlapping")) {
    renderData.iconCls = `b-fa b-fa-exclamation-triangle`;
    renderData.eventColor = colors.RED;
  }

  return {
    renderData
  };
}
